@@ -57,8 +57,12 @@ class BaseTag(object):
 
     def __str__(self):
         if self.self_closed:
+            if self.meta_content is None:
+                return ''
             return self.meta_content
         else:
+            if self.tag_value is None:
+                return ''
             return self.tag_value
 
     def __len__(self):
@@ -83,9 +87,13 @@ class TitleTag(BaseTag):
                 self.tag_value = kwargs['value']
 
     def __str__(self):
+        if self.tag_value is None:
+            return ''
         return self.tag_value
 
     def __len__(self):
+        if self.tag_value is None:
+            return 0
         return len(self.tag_value)
 
 
@@ -104,13 +112,14 @@ class BaseMetatag(BaseTag):
         if 'name' in kwargs:
             self.meta_name = kwargs['name']
 
-    def __unicode__(self):
-        return self.meta_content
-
     def __str__(self):
+        if self.meta_content is None:
+            return ''
         return self.meta_content
 
     def __len__(self):
+        if self.meta_content is None:
+            return 0
         return len(self.meta_content)
 
 
@@ -159,7 +168,9 @@ class ImageMetaTag(BaseMetatag):
         return self.meta_content
 
     def __str__(self):
-        return str(self.meta_content)
+        if self.meta_content is None:
+            return ''
+        return self.meta_content
 
 
 class KeywordsTag(BaseMetatag):
